==> component-schedule-1.2.19-20191218.124046-2-sources.jar: com/bxm/newidea/component/schedule/config/XxlJobConfiguration.java <==
package com.bxm.newidea.component.schedule.config;

import com.bxm.component.graceful.shutdown.event.ShutdownEvent;
import com.bxm.newidea.component.schedule.ScheduleService;
import com.bxm.newidea.component.schedule.rpc.ScheduleFeignService;
import com.bxm.newidea.component.schedule.rpc.ScheduleServiceImpl;
import com.netflix.appinfo.EurekaInstanceConfig;
import com.xxl.job.core.executor.impl.XxlJobSpringExecutor;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.cloud.commons.util.InetUtils;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.event.EventListener;
import org.springframework.core.Ordered;
import org.springframework.core.annotation.Order;

/**
 * xxl-job config
 * @author xuxueli 2017-04-28
 */
@SuppressWarnings("SpringJavaInjectionPointsAutowiringInspection")
@Data
@Slf4j
@Configuration
@ConfigurationProperties(prefix = "xxl.job.executor")
@ConditionalOnMissingClass("org.springframework.test.context.junit4.SpringRunner")
public class XxlJobConfiguration {
    private static final String EXECUTOR_IP = "executorIp";

    private static final int DEFAULT_PORT = 19099;

    /**
     * 调度服务地址，多个地址使用英文逗号分隔
     * 必须配置
     */
    private String adminAddresses;

    /**
     * 当前应用的名称
     * 如未配置则将获取当前服务的默认服务名
     */
    private String appName;

    /**
     * 引用该模块的服务部署设备实际IP，用于调度服务回调
     * 如未配置将尝试通过网卡获取
     */
    private String ip;

    /**
     * 对调度服务暴露的端口，用于调度服务回调
     * 如未配置将使用默认端口，注意多服务部署时的端口冲突
     */
    private int port = DEFAULT_PORT;

    /**
     * 访问凭证，如果配置需要与调度服务保持一致，用于安全性数据传输
     * 非必须，可以为空
     */
    private String accessToken;

    /**
     * 日志文件路径
     */
    private String logPath;

    /**
     * 日志清理周期
     */
    private int logRetentionDays;

    private final EurekaInstanceConfig instance;

    private final InetUtils inetUtils;


    public XxlJobConfiguration(@Autowired(required = false) EurekaInstanceConfig instance,
                               @Autowired(required = false) InetUtils inetUtils) {
        this.instance = instance;
        this.inetUtils = inetUtils;
    }

    @Bean
    public ScheduleService scheduleService(ScheduleFeignService scheduleFeignService) {
        return new ScheduleServiceImpl(this, scheduleFeignService);
    }

    @Bean
    public BeanByNameHandler beanByNameHandler() {
        return new BeanByNameHandler();
    }

    @Bean(initMethod = "start", destroyMethod = "destroy")
    @ConditionalOnProperty(name = "xxl.job.executor.app-name")
    @ConditionalOnMissingClass("org.springframework.test.context.junit4.SpringRunner")
    public XxlJobSpringExecutor xxlJobExecutor() {
        XxlJobSpringExecutor xxlJobSpringExecutor = new XxlJobSpringExecutor();

        if (StringUtils.isBlank(appName)) {
            if (null != instance) {
                appName = instance.getAppname();
            } else {
                throw new IllegalArgumentException("使用调度服务，必须提供xxl.job.executor.app-name配置属性");
            }
        }

        if (StringUtils.isBlank(ip)) {
            ip = System.getProperty(EXECUTOR_IP);
            if (StringUtils.isBlank(ip)) {
                if (null != inetUtils) {
                    ip = inetUtils.findFirstNonLoopbackHostInfo().getIpAddress();
                } else {
                    throw new IllegalArgumentException("使用调度服务，必须提供xxl.job.executor.ip配置属性");
                }
            }
        }

        if (StringUtils.isBlank(adminAddresses)) {
            throw new IllegalArgumentException("使用调度服务，必须提供xxl.job.executor.admin-address配置属性");
        }

        if (DEFAULT_PORT == port) {
            log.info("调度服务回调接口使用了默认的[{}]端口，请注意部署时的端口冲突问题", DEFAULT_PORT);
        }

        xxlJobSpringExecutor.setAdminAddresses(adminAddresses);
        xxlJobSpringExecutor.setAppName(appName);
        xxlJobSpringExecutor.setIp(ip);
        xxlJobSpringExecutor.setPort(port);
        xxlJobSpringExecutor.setAccessToken(accessToken);
        xxlJobSpringExecutor.setLogPath(logPath);
        xxlJobSpringExecutor.setLogRetentionDays(logRetentionDays);

        return xxlJobSpringExecutor;
    }

    /**
     * 响应自定义的shutdown event
     * 将执行器服务下线，并阻塞一段时间，避免客户端缓存
     * @param event
     */
    @Order(Ordered.HIGHEST_PRECEDENCE)
    @EventListener(ShutdownEvent.class)
    public void onApplicationEvent(ShutdownEvent event) {
        xxlJobExecutor().destroy();
    }

}

==> component-schedule-1.2.20-20200227.101944-7-sources.jar: com/bxm/newidea/component/schedule/config/XxlJobConfiguration.java <==
package com.bxm.newidea.component.schedule.config;

import com.bxm.component.graceful.shutdown.event.ShutdownEvent;
import com.bxm.newidea.component.schedule.ScheduleService;
import com.bxm.newidea.component.schedule.rpc.DefaultScheduleFeignService;
import com.bxm.newidea.component.schedule.rpc.ScheduleFeignService;
import com.bxm.newidea.component.schedule.rpc.ScheduleServiceImpl;
import com.bxm.newidea.component.schedule.task.ScheduleTask;
import com.netflix.appinfo.EurekaInstanceConfig;
import com.xxl.job.core.executor.impl.XxlJobSpringExecutor;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingClass;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.event.ApplicationStartedEvent;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.cloud.commons.util.InetUtils;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.event.EventListener;
import org.springframework.core.Ordered;
import org.springframework.core.annotation.Order;

import java.util.Map;

/**
 * xxl-job config
 * @author xuxueli 2017-04-28
 */
@SuppressWarnings("SpringJavaInjectionPointsAutowiringInspection")
@Data
@Slf4j
@Configuration
@ConfigurationProperties(prefix = "xxl.job.executor")
@ConditionalOnMissingClass("org.springframework.test.context.junit4.SpringRunner")
public class XxlJobConfiguration {
    private static final String EXECUTOR_IP = "executorIp";

    private static final int DEFAULT_PORT = 19099;

    /**
     * 调度服务地址，多个地址使用英文逗号分隔
     * 必须配置
     */
    private String adminAddresses;

    /**
     * 当前应用的名称
     * 如未配置则将获取当前服务的默认服务名
     */
    private String appName;

    /**
     * 引用该模块的服务部署设备实际IP，用于调度服务回调
     * 如未配置将尝试通过网卡获取
     */
    private String ip;

    /**
     * 对调度服务暴露的端口，用于调度服务回调
     * 如未配置将使用默认端口，注意多服务部署时的端口冲突
     */
    private int port = DEFAULT_PORT;

    /**
     * 访问凭证，如果配置需要与调度服务保持一致，用于安全性数据传输
     * 非必须，可以为空
     */
    private String accessToken;

    /**
     * 日志文件路径
     */
    private String logPath;

    /**
     * 日志清理周期
     */
    private int logRetentionDays;

    private final EurekaInstanceConfig instance;

    private final InetUtils inetUtils;


    public XxlJobConfiguration(@Autowired(required = false) EurekaInstanceConfig instance,
                               @Autowired(required = false) InetUtils inetUtils) {
        this.instance = instance;
        this.inetUtils = inetUtils;
    }

    @Autowired(required = false)
    private ScheduleFeignService scheduleFeignService;

    @Bean
    @ConditionalOnProperty(name = "xxl.job.executor.mock")
    public ScheduleFeignService scheduleFeignService(){
        log.info("启用mock调度服务" );
        return new DefaultScheduleFeignService();
    }

    @Bean
    public ScheduleService scheduleService() {
        if(null == scheduleFeignService){
            log.info("未启用Feign，使用默认实现的ScheduleFeignService");
            scheduleFeignService = new DefaultScheduleFeignService();
        }
        return new ScheduleServiceImpl(this, scheduleFeignService);
    }

    @Bean
    public BeanByNameHandler beanByNameHandler() {
        return new BeanByNameHandler();
    }

    @Bean(initMethod = "start", destroyMethod = "destroy")
    @ConditionalOnProperty(name = "xxl.job.executor.app-name")
    @ConditionalOnMissingClass("org.springframework.test.context.junit4.SpringRunner")
    public XxlJobSpringExecutor xxlJobExecutor() {
        XxlJobSpringExecutor xxlJobSpringExecutor = new XxlJobSpringExecutor();

        if (StringUtils.isBlank(appName)) {
            if (null != instance) {
                appName = instance.getAppname();
            } else {
                throw new IllegalArgumentException("使用调度服务，必须提供xxl.job.executor.app-name配置属性");
            }
        }

        if (StringUtils.isBlank(ip)) {
            ip = System.getProperty(EXECUTOR_IP);
            if (StringUtils.isBlank(ip)) {
                if (null != inetUtils) {
                    ip = inetUtils.findFirstNonLoopbackHostInfo().getIpAddress();
                } else {
                    throw new IllegalArgumentException("使用调度服务，必须提供xxl.job.executor.ip配置属性");
                }
            }
        }

        if (StringUtils.isBlank(adminAddresses)) {
            throw new IllegalArgumentException("使用调度服务，必须提供xxl.job.executor.admin-address配置属性");
        }

        if (DEFAULT_PORT == port) {
            log.info("调度服务回调接口使用了默认的[{}]端口，请注意部署时的端口冲突问题", DEFAULT_PORT);
        }

        xxlJobSpringExecutor.setAdminAddresses(adminAddresses);
        xxlJobSpringExecutor.setAppName(appName);
        xxlJobSpringExecutor.setIp(ip);
        xxlJobSpringExecutor.setPort(port);
        xxlJobSpringExecutor.setAccessToken(accessToken);
        xxlJobSpringExecutor.setLogPath(logPath);
        xxlJobSpringExecutor.setLogRetentionDays(logRetentionDays);

        return xxlJobSpringExecutor;
    }

    @Order(Ordered.HIGHEST_PRECEDENCE)
    @EventListener(ApplicationStartedEvent.class)
    public void initTask(ApplicationStartedEvent event){
        //获取spring中配置的调度任务
        Map<String, ScheduleTask> taskMap = event.getApplicationContext().getBeansOfType(ScheduleTask.class);
        log.info("初始化定时任务，任务数量：[{}]" , taskMap.size());
        if (taskMap.size() > 0) {
            taskMap.values().forEach(task -> {
                log.info("初始化定时任务，任务名称：[{}],任务描述：[{}]",task.taskName(),task.description());
                scheduleService().push(task);
            });
        }
    }

    /**
     * 响应自定义的shutdown event
     * 将执行器服务下线，并阻塞一段时间，避免客户端缓存
     * @param event
     */
    @Order(Ordered.HIGHEST_PRECEDENCE)
    @EventListener(ShutdownEvent.class)
    public void onApplicationEvent(ShutdownEvent event) {
        xxlJobExecutor().destroy();
    }

}
